@@ -61,7 +61,7 @@ var kotti = {
     kotti.dirty_forms = function(node) {
         var forms = $("form").not("[class~=dirty-ignore]");
         $(window).unbind('beforeunload');
-        forms.submit(function() { $(window).unbind('beforeunload') });
+        forms.submit(function() { $(window).unbind('beforeunload'); });
         if (tinyMCE != undefined)
             tinyMCE.triggerSave(true);
         var initial = forms.serialize();
@@ -131,17 +131,18 @@ var kotti = {
         });
     };
 
-    $(document).ready(function() {
+    kotti.main = function(handlers) {
         var node = $('html');
-        $.each([
-            kotti.messages, kotti.ajax_forms, kotti.dirty_forms,
-            kotti.dropdowns, kotti.collapse, kotti.hover_link_enable
-        ], function(index, func) {
+        if (!handlers) {
+            handlers = [
+                kotti.messages, kotti.ajax_forms, kotti.dirty_forms,
+                kotti.dropdowns, kotti.collapse, kotti.hover_link_enable
+            ];
+        }
+        $.each(handlers, function(index, func) {
             kotti.dom_changed_handlers.push(func);
         });
-        deform.load();
         kotti.dom_changed(node);
-    });
-
+    };
 
  })(jQuery);
