@@ -3,7 +3,6 @@ from pyramid.exceptions import Forbidden
 from pyramid.httpexceptions import HTTPFound
 from pyramid.security import has_permission
 from pyramid.url import resource_url
-from pyramid.view import is_response
 import colander
 from deform import Form
 from deform.widget import RichTextWidget
@@ -14,7 +13,7 @@ from kotti import DBSession
 from kotti.resources import Node
 from kotti.resources import Document
 from kotti.security import view_permitted
-from kotti.views.util import TemplateAPIEdit
+from kotti.views.util import template_api
 from kotti.views.util import addable_types
 from kotti.views.util import title_to_name
 from kotti.views.util import disambiguate_name
@@ -26,7 +25,7 @@ kotti_templates = resource_filename('kotti', 'templates/edit/widgets')
 search_path = (kotti_templates, deform_templates)
 Form.set_zpt_renderer(search_path)
 
-class NodeSchema(colander.MappingSchema):
+class ContentSchema(colander.MappingSchema):
     title = colander.SchemaNode(colander.String())
     description = colander.SchemaNode(
         colander.String(),
@@ -34,7 +33,7 @@ class NodeSchema(colander.MappingSchema):
         missing=u"",
         )
 
-class DocumentSchema(NodeSchema):
+class DocumentSchema(ContentSchema):
     body = colander.SchemaNode(
         colander.String(),
         widget=RichTextWidget(theme='advanced'),
@@ -69,7 +68,7 @@ def add_node(context, request):
     # Swap first and second possible parents if there's no content in
     # 'possible_parents[0]' yet.  This makes the parent then the
     # default choice in the form:
-    api = TemplateAPIEdit(context, request)
+    api = template_api(context, request)
     if not api.list_children() and len(possible_parents) > 1:
         possible_parents[0], possible_parents[1] = (
             possible_parents[1], possible_parents[0])
@@ -158,47 +157,54 @@ def move_node(context, request):
             location = resource_url(context, request) + '@@move'
             return HTTPFound(location=location)
 
-    return {
-        'api': TemplateAPIEdit(context, request),
-        }
+    return {}
 
+def generic_edit(context, request, schema, form_factory=Form, **kwargs):
+    api = template_api(context, request)
+    api.first_heading=u'<h1>Edit <em>%s</em></h1>' % context.title
+    api.page_title = u'Edit %s - %s' % (context.title, api.site_title)
 
-def generic_edit(context, request, schema):
-    form = Form(schema, buttons=('save', 'cancel'))
-    rendered = FormController(form)(context, request)
-    if is_response(rendered):
+    form = form_factory(schema, buttons=('save', 'cancel'), action=request.url)
+    rendered = FormController(form, **kwargs)(context, request)
+    if request.is_response(rendered):
         return rendered
-    return {
-        'api': TemplateAPIEdit(context, request),
-        'form': rendered,
-        }
 
-def generic_add(context, request, schema, factory, title):
-    api = TemplateAPIEdit(
-        context, request,
-        first_heading=u'<h1>Add %s to <em>%s</em></h1>' % (
-            title, context.title)
-        )
-    form = Form(schema, buttons=('save', 'cancel'))
-    rendered = FormController(form, add=factory)(context, request)
-    if is_response(rendered):
-        return rendered
     return {
         'api': api,
         'form': rendered,
         }
 
-@ensure_view_selector
-def edit_document(context, request):
-    return generic_edit(context, request, DocumentSchema())
+def generic_add(context, request, schema, add, title, form_factory=Form,
+                **kwargs):
+    api = template_api(context, request)
+    api.first_heading = u'<h1>Add %s to <em>%s</em></h1>' % (
+        title, context.title)
+    api.page_title=u'Add %s to %s - %s' % (title, context.title, api.site_title)
 
-def add_document(context, request):
-    return generic_add(
-        context, request, DocumentSchema(), Document, u'document')
+    form = form_factory(schema, buttons=('save', 'cancel'), action=request.url)
+    rendered = FormController(form, add=add, **kwargs)(context, request)
+    if request.is_response(rendered):
+        return rendered
+
+    return {
+        'api': api,
+        'form': rendered,
+        }
+
+def make_generic_edit(schema, **kwargs):
+    @ensure_view_selector
+    def view(context, request):
+        return generic_edit(context, request, schema, **kwargs)
+    return view
+
+def make_generic_add(schema, add, title, **kwargs):
+    def view(context, request):
+        return generic_add(context, request, schema, add, title, **kwargs)
+    return view
 
 def includeme(config):
     config.add_view(
-        edit_document,
+        make_generic_edit(DocumentSchema()),
         context=Document,
         name='edit',
         permission='edit',
@@ -206,7 +212,7 @@ def includeme(config):
         )
 
     config.add_view(
-        add_document,
+        make_generic_add(DocumentSchema(), Document, u'document'),
         name=Document.type_info.add_view,
         permission='add',
         renderer='../templates/edit/node.pt',
