@@ -10,6 +10,7 @@ from pyramid.i18n import get_locale_name
 from pyramid.location import inside
 from pyramid.location import lineage
 from pyramid.renderers import get_renderer
+from pyramid.renderers import render
 from pyramid.security import has_permission
 from pyramid.url import resource_url
 from pyramid.view import render_view_to_response
@@ -39,6 +40,28 @@ def add_renderer_globals(event):
             api = template_api(event['context'], event['request'])
         event['api'] = api
 
+class Slots(object):
+    def __init__(self, context, request):
+        self.context = context
+        self.request = request
+    
+    def __getattr__(self, name):
+        for event_type in slot_events:
+            if event_type.name == name:
+                break
+        else:
+            raise AttributeError(name)
+        value = []
+        event = event_type(self.context, self.request)
+        for snippet in objectevent_listeners(event):
+            if snippet is not None:
+                if isinstance(snippet, list):
+                    value.extend(snippet)
+                else:
+                    value.append(snippet)
+        setattr(self, name, value)
+        return value
+
 class TemplateAPI(object):
     """This implements the 'api' object that's passed to all
     templates.
@@ -71,6 +94,8 @@ class TemplateAPI(object):
         if getattr(request, 'template_api', None) is None:
             request.template_api = self
 
+        self.slots = Slots(context, request)
+
         self.__dict__.update(kwargs)
 
     def __getitem__(self, dottedname):
@@ -139,6 +164,9 @@ class TemplateAPI(object):
             request = self.request
         return render_view(context, request, name, secure)
 
+    def render_template(self, renderer, **kwargs):
+        return render(renderer, kwargs, self.request)
+
     def list_children(self, context=None, permission='view'):
         if context is None:
             context = self.context
@@ -173,20 +201,6 @@ class TemplateAPI(object):
             h, urllib.urlencode(query))
         return url
 
-    @reify
-    def slots(self):
-        value = {}
-        for event_type in slot_events:
-            event = event_type(self.context, self.request)
-            this_slots = value[event.name] = []
-            for snippet in objectevent_listeners(event):
-                if snippet is not None:
-                    if isinstance(snippet, list):
-                        this_slots.extend(snippet)
-                    else:
-                        this_slots.append(snippet)
-        return value
-
     @reify
     def locale_name(self):
         return get_locale_name(self.request)
